@@ -30,7 +30,7 @@
 #include "common/specialvalues.h"
 #include "resourcescoringadaptor.h"
 
-KAMD_EXPORT_PLUGIN(sqliteplugin, StatsPlugin, "kactivitymanagerd-plugin-sqlite.json")
+K_PLUGIN_CLASS_WITH_JSON(StatsPlugin, "kactivitymanagerd-plugin-sqlite.json")
 
 StatsPlugin *StatsPlugin::s_instance = nullptr;
 
@@ -89,7 +89,7 @@ void StatsPlugin::loadConfiguration()
     if (m_whatToRemember == SpecificApplications) {
         auto apps = conf.readEntry(m_blockedByDefault ? "allowed-applications" : "blocked-applications", QStringList());
 
-        m_apps.insert(apps.cbegin(), apps.cend());
+        m_apps.unite({apps.begin(), apps.end()});
     }
 
     // Delete old events, as per configuration.
